===============================
tuning_box
===============================

Tuning Box - configuration storage for your clouds

Please feel here a long description which must be at least 3 lines wrapped on
80 cols, so that distribution package maintainers can use it in their packages.
Note that this is a hard requirement.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/tuning_box
* Source: http://git.openstack.org/cgit/openstack/tuning_box
* Bugs: http://bugs.launchpad.net/tuning_box

Features
--------

* TODO